/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

import { useMemo } from 'react';
import { IconName } from '@blueprintjs/core';

import type { PluginConfigConnectionType } from '@/plugins';
import { PluginConfig, PluginType } from '@/plugins';

export type MenuItemType = {
  key: string;
  title: string;
  icon?: IconName;
  iconUrl?: string;
  path: string;
  children?: MenuItemType[];
  target?: boolean;
  isBeta?: boolean;
};

export const useMenu = () => {
  const getGrafanaUrl = () => {
    const suffix = '/d/lCO8w-pVk/homepage?orgId=1';
    const { protocol, hostname } = window.location;

    return process.env.LOCAL ? `${protocol}//${hostname}:3002${suffix}` : `/grafana${suffix}`;
  };

  return useMemo(
    () =>
      [
        {
          key: 'project',
          title: 'Projects',
          icon: 'home',
          path: '/projects',
        },
        {
          key: 'connection',
          title: 'Connections',
          icon: 'data-connection',
          path: '/connections',
          children: (
            PluginConfig.filter((p) =>
              [PluginType.Connection, PluginType.Incoming_Connection].includes(p.type),
            ) as PluginConfigConnectionType[]
          ).map((it) => ({
            key: it.plugin,
            title: it.name,
            iconUrl: it.icon,
            path: `/connections/${it.plugin}`,
            isBeta: it.isBeta,
          })),
        },
        {
          key: 'blueprint',
          title: 'Blueprints',
          icon: 'timeline-events',
          path: '/blueprints',
          children: [
            {
              key: 'create-blueprint',
              title: 'Create Blueprint',
              icon: 'git-pull',
              path: '/blueprints/create',
            },
          ],
        },
        {
          key: 'transformation',
          title: 'Transformation',
          icon: 'function',
          path: '/transformations',
        },
        {
          key: 'dashboard',
          title: 'Dashboard',
          icon: 'dashboard',
          path: getGrafanaUrl(),
          target: true,
        },
      ] as MenuItemType[],
    [],
  );
};
